# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CustomizedCfgArgs', 'CustomizedCfg']

@pulumi.input_type
class CustomizedCfgArgs:
    def __init__(__self__, *,
                 customized_cfg_content: pulumi.Input[builtins.str],
                 customized_cfg_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]] = None):
        """
        The set of arguments for constructing a CustomizedCfg resource.
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        """
        pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> pulumi.Input[builtins.str]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @customized_cfg_content.setter
    def customized_cfg_content(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "customized_cfg_content", value)

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> pulumi.Input[builtins.str]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @customized_cfg_name.setter
    def customized_cfg_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "customized_cfg_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CustomizedCfgState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_id: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 listeners: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomizedCfg resources.
        :param pulumi.Input[builtins.str] created_time: 个性化配置的创建时间。
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_id: 个性化配置的 ID 。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        :param pulumi.Input[builtins.str] status: 个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        :param pulumi.Input[builtins.str] updated_time: 个性化配置的最近操作时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if customized_cfg_content is not None:
            pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        if customized_cfg_id is not None:
            pulumi.set(__self__, "customized_cfg_id", customized_cfg_id)
        if customized_cfg_name is not None:
            pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if listeners is not None:
            pulumi.set(__self__, "listeners", listeners)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @customized_cfg_content.setter
    def customized_cfg_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_content", value)

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @customized_cfg_id.setter
    def customized_cfg_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_id", value)

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @customized_cfg_name.setter
    def customized_cfg_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "customized_cfg_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def listeners(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]]:
        return pulumi.get(self, "listeners")

    @listeners.setter
    def listeners(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgListenerArgs']]]]):
        pulumi.set(self, "listeners", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CustomizedCfgTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:alb/customizedCfg:CustomizedCfg")
class CustomizedCfg(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
                 __props__=None):
        """
        ALB 提供监听维度的个性化配置功能。通过控制台可以创建并管理常规的 NGINX 配置策略，在监听器详情页一键关联配置策略，无需提交工单即可完成满足业务需求的个性化配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_customized_cfg_demo = bytepluscc.alb.CustomizedCfg("ALBCustomizedCfgDemo",
            customized_cfg_name="ccapi-test",
            description="testdesc",
            customized_cfg_content=\"\"\"ssl_ciphers ECDHE-ECDSA-AES128-GCM-SHA256;\\x0d
        ssl_protocols TLSv1.2 TLSv1.1 TLSv1;\\x0d
        client_max_body_size 60M;\\x0d
        keepalive_timeout 77s;\\x0d
        proxy_connect_timeout 4s;\\x0d
        proxy_request_buffering off;\\x0d
        proxy_ignore_client_abort off;\\x0d
        proxy_read_timeout 60s;\\x0d
        proxy_send_timeout 60s;\\x0d
        client_header_timeout 60s;\\x0d
        client_body_timeout 60s;\\x0d
        send_timeout 60s;\\x0d
        ssl_verify_depth 3;\\x0d
        \"\"\",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/customizedCfg:CustomizedCfg example "customized_cfg_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomizedCfgArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ALB 提供监听维度的个性化配置功能。通过控制台可以创建并管理常规的 NGINX 配置策略，在监听器详情页一键关联配置策略，无需提交工单即可完成满足业务需求的个性化配置。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        a_lb_customized_cfg_demo = bytepluscc.alb.CustomizedCfg("ALBCustomizedCfgDemo",
            customized_cfg_name="ccapi-test",
            description="testdesc",
            customized_cfg_content=\"\"\"ssl_ciphers ECDHE-ECDSA-AES128-GCM-SHA256;\\x0d
        ssl_protocols TLSv1.2 TLSv1.1 TLSv1;\\x0d
        client_max_body_size 60M;\\x0d
        keepalive_timeout 77s;\\x0d
        proxy_connect_timeout 4s;\\x0d
        proxy_request_buffering off;\\x0d
        proxy_ignore_client_abort off;\\x0d
        proxy_read_timeout 60s;\\x0d
        proxy_send_timeout 60s;\\x0d
        client_header_timeout 60s;\\x0d
        client_body_timeout 60s;\\x0d
        send_timeout 60s;\\x0d
        ssl_verify_depth 3;\\x0d
        \"\"\",
            project_name="default",
            tags=[{
                "key": "env",
                "value": "test",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:alb/customizedCfg:CustomizedCfg example "customized_cfg_id"
        ```

        :param str resource_name: The name of the resource.
        :param CustomizedCfgArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomizedCfgArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
                 customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomizedCfgArgs.__new__(CustomizedCfgArgs)

            if customized_cfg_content is None and not opts.urn:
                raise TypeError("Missing required property 'customized_cfg_content'")
            __props__.__dict__["customized_cfg_content"] = customized_cfg_content
            if customized_cfg_name is None and not opts.urn:
                raise TypeError("Missing required property 'customized_cfg_name'")
            __props__.__dict__["customized_cfg_name"] = customized_cfg_name
            __props__.__dict__["description"] = description
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_time"] = None
            __props__.__dict__["customized_cfg_id"] = None
            __props__.__dict__["listeners"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(CustomizedCfg, __self__).__init__(
            'bytepluscc:alb/customizedCfg:CustomizedCfg',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_content: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_id: Optional[pulumi.Input[builtins.str]] = None,
            customized_cfg_name: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            listeners: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgListenerArgs', 'CustomizedCfgListenerArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CustomizedCfgTagArgs', 'CustomizedCfgTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'CustomizedCfg':
        """
        Get an existing CustomizedCfg resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 个性化配置的创建时间。
        :param pulumi.Input[builtins.str] customized_cfg_content: 个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        :param pulumi.Input[builtins.str] customized_cfg_id: 个性化配置的 ID 。
        :param pulumi.Input[builtins.str] customized_cfg_name: 个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        :param pulumi.Input[builtins.str] description: 个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        :param pulumi.Input[builtins.str] project_name: 个性化配置所属项目名称。
        :param pulumi.Input[builtins.str] status: 个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        :param pulumi.Input[builtins.str] updated_time: 个性化配置的最近操作时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomizedCfgState.__new__(_CustomizedCfgState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["customized_cfg_content"] = customized_cfg_content
        __props__.__dict__["customized_cfg_id"] = customized_cfg_id
        __props__.__dict__["customized_cfg_name"] = customized_cfg_name
        __props__.__dict__["description"] = description
        __props__.__dict__["listeners"] = listeners
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return CustomizedCfg(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def listeners(self) -> pulumi.Output[Sequence['outputs.CustomizedCfgListener']]:
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CustomizedCfgTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EndpointPublicAddressArgs', 'EndpointPublicAddress']

@pulumi.input_type
class EndpointPublicAddressArgs:
    def __init__(__self__, *,
                 eip_id: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a EndpointPublicAddress resource.
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        pulumi.set(__self__, "eip_id", eip_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if new_address_prefix is not None:
            pulumi.set(__self__, "new_address_prefix", new_address_prefix)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if upgrade_region_domain is not None:
            pulumi.set(__self__, "upgrade_region_domain", upgrade_region_domain)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Input[builtins.str]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @new_address_prefix.setter
    def new_address_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_address_prefix", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @upgrade_region_domain.setter
    def upgrade_region_domain(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "upgrade_region_domain", value)


@pulumi.input_type
class _EndpointPublicAddressState:
    def __init__(__self__, *,
                 addr_type: Optional[pulumi.Input[builtins.str]] = None,
                 address: Optional[pulumi.Input[builtins.str]] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 vi_pv6: Optional[pulumi.Input[builtins.str]] = None,
                 vip: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering EndpointPublicAddress resources.
        :param pulumi.Input[builtins.str] addr_type: 连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        :param pulumi.Input[builtins.str] address: IP 地址或者域名。
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        :param pulumi.Input[builtins.str] vi_pv6: 连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        :param pulumi.Input[builtins.str] vip: 连接地址所对应的 IPv4 地址。
        """
        if addr_type is not None:
            pulumi.set(__self__, "addr_type", addr_type)
        if address is not None:
            pulumi.set(__self__, "address", address)
        if eip_id is not None:
            pulumi.set(__self__, "eip_id", eip_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if new_address_prefix is not None:
            pulumi.set(__self__, "new_address_prefix", new_address_prefix)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if upgrade_region_domain is not None:
            pulumi.set(__self__, "upgrade_region_domain", upgrade_region_domain)
        if vi_pv6 is not None:
            pulumi.set(__self__, "vi_pv6", vi_pv6)
        if vip is not None:
            pulumi.set(__self__, "vip", vip)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        """
        return pulumi.get(self, "addr_type")

    @addr_type.setter
    def addr_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "addr_type", value)

    @property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "address", value)

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @eip_id.setter
    def eip_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "eip_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @new_address_prefix.setter
    def new_address_prefix(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "new_address_prefix", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @upgrade_region_domain.setter
    def upgrade_region_domain(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "upgrade_region_domain", value)

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        """
        return pulumi.get(self, "vi_pv6")

    @vi_pv6.setter
    def vi_pv6(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vi_pv6", value)

    @property
    @pulumi.getter
    def vip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")

    @vip.setter
    def vip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vip", value)


@pulumi.type_token("bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress")
class EndpointPublicAddress(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        开启公网访问，以便 VPC 外的设备来访问 Redis 实例。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_endpoint_public_address_demo = bytepluscc.redis.EndpointPublicAddress("RedisEndpointPublicAddressDemo",
            instance_id="redis-cnlfii2cw1xxxxxx",
            port=6379,
            eip_id="eip-w08rcc38bsw0865yxxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress example "instance_id|eip_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EndpointPublicAddressArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        开启公网访问，以便 VPC 外的设备来访问 Redis 实例。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_endpoint_public_address_demo = bytepluscc.redis.EndpointPublicAddress("RedisEndpointPublicAddressDemo",
            instance_id="redis-cnlfii2cw1xxxxxx",
            port=6379,
            eip_id="eip-w08rcc38bsw0865yxxxxx")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress example "instance_id|eip_id"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointPublicAddressArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointPublicAddressArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 eip_id: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
                 port: Optional[pulumi.Input[builtins.int]] = None,
                 upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointPublicAddressArgs.__new__(EndpointPublicAddressArgs)

            if eip_id is None and not opts.urn:
                raise TypeError("Missing required property 'eip_id'")
            __props__.__dict__["eip_id"] = eip_id
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["new_address_prefix"] = new_address_prefix
            __props__.__dict__["port"] = port
            __props__.__dict__["upgrade_region_domain"] = upgrade_region_domain
            __props__.__dict__["addr_type"] = None
            __props__.__dict__["address"] = None
            __props__.__dict__["vi_pv6"] = None
            __props__.__dict__["vip"] = None
        super(EndpointPublicAddress, __self__).__init__(
            'bytepluscc:redis/endpointPublicAddress:EndpointPublicAddress',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            addr_type: Optional[pulumi.Input[builtins.str]] = None,
            address: Optional[pulumi.Input[builtins.str]] = None,
            eip_id: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            new_address_prefix: Optional[pulumi.Input[builtins.str]] = None,
            port: Optional[pulumi.Input[builtins.int]] = None,
            upgrade_region_domain: Optional[pulumi.Input[builtins.bool]] = None,
            vi_pv6: Optional[pulumi.Input[builtins.str]] = None,
            vip: Optional[pulumi.Input[builtins.str]] = None) -> 'EndpointPublicAddress':
        """
        Get an existing EndpointPublicAddress resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] addr_type: 连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        :param pulumi.Input[builtins.str] address: IP 地址或者域名。
        :param pulumi.Input[builtins.str] eip_id: 弹性公网 IP 的 ID。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] new_address_prefix: 修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        :param pulumi.Input[builtins.int] port: 端口号。
        :param pulumi.Input[builtins.bool] upgrade_region_domain: 是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        :param pulumi.Input[builtins.str] vi_pv6: 连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        :param pulumi.Input[builtins.str] vip: 连接地址所对应的 IPv4 地址。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointPublicAddressState.__new__(_EndpointPublicAddressState)

        __props__.__dict__["addr_type"] = addr_type
        __props__.__dict__["address"] = address
        __props__.__dict__["eip_id"] = eip_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["new_address_prefix"] = new_address_prefix
        __props__.__dict__["port"] = port
        __props__.__dict__["upgrade_region_domain"] = upgrade_region_domain
        __props__.__dict__["vi_pv6"] = vi_pv6
        __props__.__dict__["vip"] = vip
        return EndpointPublicAddress(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="addrType")
    def addr_type(self) -> pulumi.Output[builtins.str]:
        """
        连接地址类型，取值范围如下：Private：私网连接地址。Public：公网连接地址。DirectLink：直连地址。说明仅启用分片集群的 Redis 实例申请了直连地址后，才会返回直连地址信息。关于连接地址的更多信息，请参见连接地址类型。
        """
        return pulumi.get(self, "addr_type")

    @property
    @pulumi.getter
    def address(self) -> pulumi.Output[builtins.str]:
        """
        IP 地址或者域名。
        """
        return pulumi.get(self, "address")

    @property
    @pulumi.getter(name="eipId")
    def eip_id(self) -> pulumi.Output[builtins.str]:
        """
        弹性公网 IP 的 ID。
        """
        return pulumi.get(self, "eip_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="newAddressPrefix")
    def new_address_prefix(self) -> pulumi.Output[builtins.str]:
        """
        修改后的连接地址前缀。连接地址前缀需同时满足如下要求：由小写字母、数字或连字符（-）组成。以字母开头，字母或数字结尾。长度为 8~53 个字符。修改后的连接地址需要保证全局唯一，不可以与火山引擎中任何地域下的任何连接地址重名。
        """
        return pulumi.get(self, "new_address_prefix")

    @property
    @pulumi.getter
    def port(self) -> pulumi.Output[builtins.int]:
        """
        端口号。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="upgradeRegionDomain")
    def upgrade_region_domain(self) -> pulumi.Output[builtins.bool]:
        """
        是否升级连接地址的域名后缀。取值范围如下：true：升级。false（默认值）：不升级。注意当需要升级域名后缀（即 UpgradeRegionDomain 为 true）时，必须同时传入连接地址前缀信息（即 Address 参数不允许为空。）升级域名后缀后，原有的连接会断开，请及时修改客户端的连接信息，使用新的连接地址来连接实例。连接实例的具体方法，请参见连接实例。连接地址域名后缀升级后不支持再降级回原来的后缀，请谨慎操作。升级后的连接地址域名后缀会自动包含实例所属地域信息，旧的连接地址会保留 12 小时，12 小时保留期到期后会被自动释放。更多详情，请参见升级域名后缀。
        """
        return pulumi.get(self, "upgrade_region_domain")

    @property
    @pulumi.getter(name="viPv6")
    def vi_pv6(self) -> pulumi.Output[builtins.str]:
        """
        连接地址所对应的 IPv6 地址。说明仅当实例使用了 IPv6 地址时才会返回该参数。仅私网地址和直连地址支持 IPv6 地址，公网地址不支持，因此当连接地址类型为公网地址（即 AddrType 为 Public）时，该参数值固定为空。
        """
        return pulumi.get(self, "vi_pv6")

    @property
    @pulumi.getter
    def vip(self) -> pulumi.Output[builtins.str]:
        """
        连接地址所对应的 IPv4 地址。
        """
        return pulumi.get(self, "vip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AllowListArgs', 'AllowList']

@pulumi.input_type
class AllowListArgs:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a AllowList resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_list is not None:
            pulumi.set(__self__, "user_allow_list", user_allow_list)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")

    @user_allow_list.setter
    def user_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_allow_list", value)


@pulumi.input_type
class _AllowListState:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering AllowList resources.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单中 IP 地址或 IP 地址段的数量。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id is not None:
            pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num is not None:
            pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances is not None:
            pulumi.set(__self__, "associated_instances", associated_instances)
        if ip_address is not None:
            pulumi.set(__self__, "ip_address", ip_address)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_list is not None:
            pulumi.set(__self__, "user_allow_list", user_allow_list)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单 ID。
        """
        return pulumi.get(self, "allow_list_id")

    @allow_list_id.setter
    def allow_list_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_id", value)

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单中 IP 地址或 IP 地址段的数量。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @allow_list_ip_num.setter
    def allow_list_ip_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_list_ip_num", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]:
        return pulumi.get(self, "associated_instances")

    @associated_instances.setter
    def associated_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]):
        pulumi.set(self, "associated_instances", value)

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @ip_address.setter
    def ip_address(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip_address", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")

    @user_allow_list.setter
    def user_allow_list(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_allow_list", value)


@pulumi.type_token("bytepluscc:rdspostgresql/allowList:AllowList")
class AllowList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。PostgreSQL 实例在创建后，不会绑定任何白名单，默认禁止所有 IP 地址访问实例。因此无论是通过私网还是通过公网连接访问实例，都需要先为实例配置白名单，才能保证实例可连接。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rds_postgresql_allow_list_demo = bytepluscc.rdspostgresql.AllowList("RdsPostgresqlAllowListDemo",
            allow_lists=[
                "1.2.3.4/32",
                "5.6.7.8/32",
            ],
            allow_list_category="Ordinary",
            allow_list_desc="test",
            allow_list_name="ccapi-test-1",
            allow_list_type="IPv4")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AllowListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。PostgreSQL 实例在创建后，不会绑定任何白名单，默认禁止所有 IP 地址访问实例。因此无论是通过私网还是通过公网连接访问实例，都需要先为实例配置白名单，才能保证实例可连接。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        rds_postgresql_allow_list_demo = bytepluscc.rdspostgresql.AllowList("RdsPostgresqlAllowListDemo",
            allow_lists=[
                "1.2.3.4/32",
                "5.6.7.8/32",
            ],
            allow_list_category="Ordinary",
            allow_list_desc="test",
            allow_list_name="ccapi-test-1",
            allow_list_type="IPv4")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdspostgresql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param AllowListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AllowListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ip_address: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_list: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AllowListArgs.__new__(AllowListArgs)

            __props__.__dict__["allow_list_category"] = allow_list_category
            __props__.__dict__["allow_list_desc"] = allow_list_desc
            __props__.__dict__["allow_list_name"] = allow_list_name
            __props__.__dict__["allow_list_type"] = allow_list_type
            __props__.__dict__["allow_lists"] = allow_lists
            __props__.__dict__["associated_instance_num"] = associated_instance_num
            __props__.__dict__["ip_address"] = ip_address
            __props__.__dict__["modify_mode"] = modify_mode
            __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
            __props__.__dict__["update_security_group"] = update_security_group
            __props__.__dict__["user_allow_list"] = user_allow_list
            __props__.__dict__["allow_list_id"] = None
            __props__.__dict__["allow_list_ip_num"] = None
            __props__.__dict__["associated_instances"] = None
        super(AllowList, __self__).__init__(
            'bytepluscc:rdspostgresql/allowList:AllowList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
            allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
            allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
            associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListAssociatedInstanceArgs', 'AllowListAssociatedInstanceArgsDict']]]]] = None,
            ip_address: Optional[pulumi.Input[builtins.str]] = None,
            modify_mode: Optional[pulumi.Input[builtins.str]] = None,
            security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
            update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
            user_allow_list: Optional[pulumi.Input[builtins.str]] = None) -> 'AllowList':
        """
        Get an existing AllowList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单中 IP 地址或 IP 地址段的数量。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单采用的网络协议类型。取值为 IPv4（默认值）。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        :param pulumi.Input[builtins.int] associated_instance_num: 该白名单绑定的实例数量。
        :param pulumi.Input[builtins.str] ip_address: 按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        :param pulumi.Input[builtins.str] modify_mode: 修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        :param pulumi.Input[builtins.str] user_allow_list: 安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AllowListState.__new__(_AllowListState)

        __props__.__dict__["allow_list_category"] = allow_list_category
        __props__.__dict__["allow_list_desc"] = allow_list_desc
        __props__.__dict__["allow_list_id"] = allow_list_id
        __props__.__dict__["allow_list_ip_num"] = allow_list_ip_num
        __props__.__dict__["allow_list_name"] = allow_list_name
        __props__.__dict__["allow_list_type"] = allow_list_type
        __props__.__dict__["allow_lists"] = allow_lists
        __props__.__dict__["associated_instance_num"] = associated_instance_num
        __props__.__dict__["associated_instances"] = associated_instances
        __props__.__dict__["ip_address"] = ip_address
        __props__.__dict__["modify_mode"] = modify_mode
        __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
        __props__.__dict__["update_security_group"] = update_security_group
        __props__.__dict__["user_allow_list"] = user_allow_list
        return AllowList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> pulumi.Output[builtins.str]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时无默认值，不传入时则查询所有类别的白名单。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> pulumi.Output[builtins.str]:
        """
        白名单的描述信息。长度在 200 字符以内。默认值为空字符串。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> pulumi.Output[builtins.str]:
        """
        白名单 ID。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单中 IP 地址或 IP 地址段的数量。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> pulumi.Output[builtins.str]:
        """
        白名单名称的命名规则如下：在当前地域内，白名单名称唯一。以中文、字母或下划线（*）开头。只能包含中文、字母、数字、下划线（*）和中划线（-）。长度为 1~128 个字符。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> pulumi.Output[builtins.str]:
        """
        白名单采用的网络协议类型。取值为 IPv4（默认值）。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单中包含的 IP 地址。支持以下两种格式：IP 地址格式。例如：10.23.12.24。CIDR 的 IP 地址段格式。例如：10.23.12.0/24（无类别域间路由，24 表示了地址中前缀的长度，范围为 1~32）。说明每个白名单最多可添加 300 个 IP 或 IP 地址段，当 IP 较多时，建议合并为 IP 段填入，例如10.23.12.0/24。禁止将 0.0.0.0/0 之外的形如 x.x.x.x/0 结尾的 IP 地址加入白名单。该字段不能与 UserAllowList 字段同时使用。
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> pulumi.Output[builtins.int]:
        """
        该白名单绑定的实例数量。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> pulumi.Output[Sequence['outputs.AllowListAssociatedInstance']]:
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> pulumi.Output[builtins.str]:
        """
        按 IP 地址查询白名单。支持传入多个 IP 地址，多个 IP 地址使用英文逗号（,）分隔。说明如果白名单包含了多个 IP 地址的任意子集，该白名单就会被返回。
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> pulumi.Output[builtins.str]:
        """
        修改白名单的方式。取值：Cover：覆盖，即使用 AllowList 字段的值覆盖原白名单。默认值。Append：追加，即在原白名单中增加 AllowList 字段包含的 IP 地址。Delete：删除，即在原白名单中删除 AllowList 字段包含的 IP 地址。至少需要保留一个 IP 地址。注意如需修改的白名单绑定有安全组，或需要在修改白名单时为白名单绑定安全组，则 ModifyMode 只能取值为 Cover。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> pulumi.Output[Sequence['outputs.AllowListSecurityGroupBindInfo']]:
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> pulumi.Output[builtins.bool]:
        """
        是否更新白名单所绑定的安全组。取值：true：更新。false：不更新。默认值。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowList")
    def user_allow_list(self) -> pulumi.Output[builtins.str]:
        """
        安全组之外的、需要加入白名单的 IP 地址。可输入 IP 地址或 CIDR 格式的 IP 地址段。说明该字段不能与 AllowList 字段同时使用。
        """
        return pulumi.get(self, "user_allow_list")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetTrafficMirrorFilterRuleResult',
    'AwaitableGetTrafficMirrorFilterRuleResult',
    'get_traffic_mirror_filter_rule',
    'get_traffic_mirror_filter_rule_output',
]

@pulumi.output_type
class GetTrafficMirrorFilterRuleResult:
    """
    A collection of values returned by getTrafficMirrorFilterRule.
    """
    def __init__(__self__, description=None, destination_cidr_block=None, destination_port_range=None, id=None, policy=None, priority=None, protocol=None, source_cidr_block=None, source_port_range=None, status=None, traffic_direction=None, traffic_mirror_filter_id=None, traffic_mirror_filter_rule_id=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if destination_cidr_block and not isinstance(destination_cidr_block, str):
            raise TypeError("Expected argument 'destination_cidr_block' to be a str")
        pulumi.set(__self__, "destination_cidr_block", destination_cidr_block)
        if destination_port_range and not isinstance(destination_port_range, str):
            raise TypeError("Expected argument 'destination_port_range' to be a str")
        pulumi.set(__self__, "destination_port_range", destination_port_range)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if policy and not isinstance(policy, str):
            raise TypeError("Expected argument 'policy' to be a str")
        pulumi.set(__self__, "policy", policy)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if protocol and not isinstance(protocol, str):
            raise TypeError("Expected argument 'protocol' to be a str")
        pulumi.set(__self__, "protocol", protocol)
        if source_cidr_block and not isinstance(source_cidr_block, str):
            raise TypeError("Expected argument 'source_cidr_block' to be a str")
        pulumi.set(__self__, "source_cidr_block", source_cidr_block)
        if source_port_range and not isinstance(source_port_range, str):
            raise TypeError("Expected argument 'source_port_range' to be a str")
        pulumi.set(__self__, "source_port_range", source_port_range)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if traffic_direction and not isinstance(traffic_direction, str):
            raise TypeError("Expected argument 'traffic_direction' to be a str")
        pulumi.set(__self__, "traffic_direction", traffic_direction)
        if traffic_mirror_filter_id and not isinstance(traffic_mirror_filter_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_id", traffic_mirror_filter_id)
        if traffic_mirror_filter_rule_id and not isinstance(traffic_mirror_filter_rule_id, str):
            raise TypeError("Expected argument 'traffic_mirror_filter_rule_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_filter_rule_id", traffic_mirror_filter_rule_id)

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        筛选规则的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationCidrBlock")
    def destination_cidr_block(self) -> builtins.str:
        """
        目的网段。
        """
        return pulumi.get(self, "destination_cidr_block")

    @property
    @pulumi.getter(name="destinationPortRange")
    def destination_port_range(self) -> builtins.str:
        """
        流量目的端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "destination_port_range")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def policy(self) -> builtins.str:
        """
        流量采集策略。accept：允许。即当镜像源的流量匹配该规则时，复制该流量至镜像目标进行监控分析。reject：拒绝。即当镜像源的流量匹配该规则时，不复制该流量，拒绝对该流量进行监控分析。
        """
        return pulumi.get(self, "policy")

    @property
    @pulumi.getter
    def priority(self) -> builtins.int:
        """
        筛选规则的优先级，范围为1-1000。数值越小，优先级越高。默认为1，1为最高优先级。同一筛选条件同一方向的优先级唯一。
        """
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter
    def protocol(self) -> builtins.str:
        """
        流量的协议。取值如下：all：含TCP、UDP、ICMP协议。tcp：TCP协议。udp：UDP协议。icmp：ICMP协议。
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="sourceCidrBlock")
    def source_cidr_block(self) -> builtins.str:
        """
        流量源网段。
        """
        return pulumi.get(self, "source_cidr_block")

    @property
    @pulumi.getter(name="sourcePortRange")
    def source_port_range(self) -> builtins.str:
        """
        流量源端口范围。当Protocol传入all或icmp时，无需传入本参数，默认取值-1/-1，表示不限制端口。当Protocol传入tcp或udp时，本参数为必选，取值范围1～65535，使用正斜线（/）隔开起始端口和终止端口，如1/50、80/80。
        """
        return pulumi.get(self, "source_port_range")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        筛选规则的状态。Available：可用。Deleting：删除中。Creating：创建中。Pending：修改中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="trafficDirection")
    def traffic_direction(self) -> builtins.str:
        """
        流量的方向。取值如下：ingress：入向规则。egress：出向规则。
        """
        return pulumi.get(self, "traffic_direction")

    @property
    @pulumi.getter(name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> builtins.str:
        """
        筛选条件的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_id")

    @property
    @pulumi.getter(name="trafficMirrorFilterRuleId")
    def traffic_mirror_filter_rule_id(self) -> builtins.str:
        """
        筛选规则的ID。
        """
        return pulumi.get(self, "traffic_mirror_filter_rule_id")


class AwaitableGetTrafficMirrorFilterRuleResult(GetTrafficMirrorFilterRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorFilterRuleResult(
            description=self.description,
            destination_cidr_block=self.destination_cidr_block,
            destination_port_range=self.destination_port_range,
            id=self.id,
            policy=self.policy,
            priority=self.priority,
            protocol=self.protocol,
            source_cidr_block=self.source_cidr_block,
            source_port_range=self.source_port_range,
            status=self.status,
            traffic_direction=self.traffic_direction,
            traffic_mirror_filter_id=self.traffic_mirror_filter_id,
            traffic_mirror_filter_rule_id=self.traffic_mirror_filter_rule_id)


def get_traffic_mirror_filter_rule(id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorFilterRuleResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilterRule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorFilterRule:getTrafficMirrorFilterRule', __args__, opts=opts, typ=GetTrafficMirrorFilterRuleResult).value

    return AwaitableGetTrafficMirrorFilterRuleResult(
        description=pulumi.get(__ret__, 'description'),
        destination_cidr_block=pulumi.get(__ret__, 'destination_cidr_block'),
        destination_port_range=pulumi.get(__ret__, 'destination_port_range'),
        id=pulumi.get(__ret__, 'id'),
        policy=pulumi.get(__ret__, 'policy'),
        priority=pulumi.get(__ret__, 'priority'),
        protocol=pulumi.get(__ret__, 'protocol'),
        source_cidr_block=pulumi.get(__ret__, 'source_cidr_block'),
        source_port_range=pulumi.get(__ret__, 'source_port_range'),
        status=pulumi.get(__ret__, 'status'),
        traffic_direction=pulumi.get(__ret__, 'traffic_direction'),
        traffic_mirror_filter_id=pulumi.get(__ret__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_rule_id=pulumi.get(__ret__, 'traffic_mirror_filter_rule_id'))
def get_traffic_mirror_filter_rule_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorFilterRuleResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorFilterRule


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorFilterRule:getTrafficMirrorFilterRule', __args__, opts=opts, typ=GetTrafficMirrorFilterRuleResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorFilterRuleResult(
        description=pulumi.get(__response__, 'description'),
        destination_cidr_block=pulumi.get(__response__, 'destination_cidr_block'),
        destination_port_range=pulumi.get(__response__, 'destination_port_range'),
        id=pulumi.get(__response__, 'id'),
        policy=pulumi.get(__response__, 'policy'),
        priority=pulumi.get(__response__, 'priority'),
        protocol=pulumi.get(__response__, 'protocol'),
        source_cidr_block=pulumi.get(__response__, 'source_cidr_block'),
        source_port_range=pulumi.get(__response__, 'source_port_range'),
        status=pulumi.get(__response__, 'status'),
        traffic_direction=pulumi.get(__response__, 'traffic_direction'),
        traffic_mirror_filter_id=pulumi.get(__response__, 'traffic_mirror_filter_id'),
        traffic_mirror_filter_rule_id=pulumi.get(__response__, 'traffic_mirror_filter_rule_id')))
